@@ -6,13 +6,12 @@
 #include <glib/gi18n.h>
 #include <gio/gio.h>
 #include <gtk/gtk.h>
-#include <unique/unique.h>
 #include <libappindicator/app-indicator.h>
 #include <libnotify/notify.h>
 
 extern GRand *			self_random;
 
-extern UniqueApp *		self_unique_app;
+extern GtkApplication *		self_gtk_app;
 
 extern gboolean			self_has_notify;
 extern NotifyNotification *	self_notification;
